[cello-cvs] CVS cello/cl-magick

fgoenninger fgoenninger at common-lisp.net
Mon Aug 28 18:41:19 UTC 2006


Update of /project/cello/cvsroot/cello/cl-magick
In directory clnet:/tmp/cvs-serv21072

Modified Files:
	wand-texture.lisp 
Log Message:
Changed: Added some (now inactive) print statements for debugging only.

--- /project/cello/cvsroot/cello/cl-magick/wand-texture.lisp	2006/08/23 20:20:27	1.5
+++ /project/cello/cvsroot/cello/cl-magick/wand-texture.lisp	2006/08/28 18:41:19	1.6
@@ -42,14 +42,14 @@
              (grow-sz (cons (expt 2 (ceiling (log (car (image-size self)) 2)))
 			    (expt 2 (ceiling (log (cdr (image-size self)) 2)))))
              (best-fit-sz (best-fit-cons trunc-sz (image-size self) grow-sz)))
-	#+shh (print `(texture-name> gennning texture ,self))
+	;;(print `(texture-name> gennning texture ,self)) ;; frgo: debug...
         (unless (equal (image-size self) best-fit-sz)
-          #+shhh (print `(texture-name> tex-refit ,(image-size self) to ,best-fit-sz))
+          ;;(print `(texture-name> tex-refit ,(image-size self) to ,best-fit-sz)) ;; frgo: debug...
           (magick-scale-image (mgk-wand self) (car best-fit-sz) (cdr best-fit-sz))
 ;;; gaussian-filter 0)
           (setf (image-size self) best-fit-sz))
         
         #+shhh (print `(texture-name> new image size , self ,(image-size self)))
         (let ((tx (wand-image-to-texture self)))
           (if (plusp tx)
               (setf (texture-name self) tx)
@@ -57,19 +57,20 @@
   
   
 (defun wand-texture-activate (wand)
-					;(print `(wand-texture-activate ,(texture-name wand)))
+  ;;(print `(wand-texture-activate ,(texture-name wand)))
   (ogl-tex-activate (texture-name wand)))
   
 (defparameter *textures-1* (fgn-alloc 'kt-opengl::gluint 1 :ignore))
+
 (defun wand-image-to-texture (self)
   (let ((tx (ogl-texture-gen) #+not (progn (gl-gen-textures 1 *textures-1*)
 					   (ff-elt *textures-1* gluint 0)))
 	(pixels (wand-get-image-pixels (mgk-wand self) 0 0
 				       (car (image-size self))
 				       (cdr (image-size self)))))
-    ;; (assert (not *ogl-listing-p*))
+    ;;(assert (not *ogl-listing-p*))
     (assert (plusp tx))
     ;; (cells:trc "!!!!wand-image-to-texture genning new tx: ~a" tx)
     (gl-bind-texture gl_texture_2d tx)
       
     (progn ;; useless??
@@ -86,7 +87,7 @@
     (gl-tex-image2d  gl_texture_2d 0 3 (car (image-size self)) (cdr (image-size self))
 		     0 gl_rgb gl_unsigned_byte pixels)
     (kt-opengl::glec :tex-image)
-    ;;(print `(wand-image-to-texture loaded texture sized ,(image-size self)))
+    (print `(wand-image-to-texture loaded texture sized ,(image-size self))) ;; frgo: debug...
       
     (fgn-free pixels)
     tx)) 
@@ -42,14 +42,14 @@
           (setf (image-size self) best-fit-sz))
         
-        #+shhh (print `(texture-name> new image size , self ,(image-size self)))
+       ;; (print `(texture-name> new image size , self ,(image-size self))) ;; frgo: debug...
         (let ((tx (wand-image-to-texture self)))
           (if (plusp tx)
@@ -57,19 +57,20 @@
     (assert (plusp tx))
-    ;; (cells:trc "!!!!wand-image-to-texture genning new tx: ~a" tx)
+    ;;(cells:trc "!!!!wand-image-to-texture genning new tx: ~a" tx) ;; frgo: debug...
     (gl-bind-texture gl_texture_2d tx)
       




More information about the Cello-cvs mailing list